@@ -1,4 +1,3 @@
-import copy
 from distutils.version import LooseVersion
 
 from fsspec.core import get_fs_token_paths
@@ -30,9 +29,7 @@ class ORCFunctionWrapper:
         """
         if columns == self.columns:
             return self
-        func = copy.deepcopy(self)
-        func.columns = columns
-        return func
+        return ORCFunctionWrapper(self.fs, columns, self.schema)
 
     def __call__(self, stripe_info):
         path, stripe = stripe_info
@@ -60,6 +57,7 @@ def _read_orc_stripe(fs, path, stripe, columns=None):
 
 def read_orc(path, columns=None, storage_options=None):
     """Read dataframe from ORC file(s)
+
     Parameters
     ----------
     path: str or list(str)
@@ -69,9 +67,11 @@ def read_orc(path, columns=None, storage_options=None):
         Columns to load. If None, loads all.
     storage_options: None or dict
         Further parameters to pass to the bytes backend.
+
     Returns
     -------
     Dask.DataFrame (even if there is only one column)
+
     Examples
     --------
     >>> df = dd.read_orc('https://github.com/apache/orc/raw/'
