@@ -515,7 +515,7 @@ class ArrowDatasetEngine(Engine):
         )
 
         # Process metadata to define `meta` and `index_cols`
-        meta, index_cols, categories, index = cls._generate_dd_meta(
+        meta, index_cols, categories, index, partition_info = cls._generate_dd_meta(
             schema, index, categories, partition_info
         )
 
@@ -672,8 +672,37 @@ class ArrowDatasetEngine(Engine):
             df = df.set_index(index)
         return df
 
-    @staticmethod
+    @classmethod
+    def _get_dataset_offset(cls, path, fs, append, ignore_divisions):
+        fmd = None
+        i_offset = 0
+        if append:
+            # Make sure there are existing file fragments.
+            # Otherwise there is no need to set `append=True`
+            i_offset = len(
+                list(
+                    pa_ds.dataset(path, filesystem=fs, format="parquet").get_fragments()
+                )
+            )
+            if i_offset == 0:
+                # No dataset to append to
+                return fmd, i_offset, False
+            try:
+                fmd = pq.read_metadata(fs.sep.join([path, "_metadata"]))
+            except (IOError, FileNotFoundError):
+                # No _metadata file present - No appending allowed (for now)
+                if not ignore_divisions:
+                    # TODO: Be more flexible about existing metadata.
+                    raise NotImplementedError(
+                        "_metadata file needed to `append` "
+                        "with `engine='pyarrow-dataset'` "
+                        "unless `ignore_divisions` is `True`"
+                    )
+        return fmd, i_offset, append
+
+    @classmethod
     def initialize_write(
+        cls,
         df,
         fs,
         path,
@@ -726,31 +755,19 @@ class ArrowDatasetEngine(Engine):
             # Final (inferred) schema
             schema = _schema
 
-        dataset = fmd = None
-        i_offset = 0
+        # Check that target directory exists
+        fs.mkdirs(path, exist_ok=True)
         if append and division_info is None:
             ignore_divisions = True
-        fs.mkdirs(path, exist_ok=True)
 
+        # Extract metadata and get file offset if appending
+        fmd, i_offset, append = cls._get_dataset_offset(
+            path, fs, append, ignore_divisions
+        )
+
+        # Inspect the intial metadata if appending
         if append:
-            try:
-                # Allow append if the dataset exists.
-                # Also need dataset.metadata object if
-                # ignore_divisions is False (to check divisions)
-                dataset = pq.ParquetDataset(path, filesystem=fs)
-                if not dataset.metadata and not ignore_divisions:
-                    # TODO: Be more flexible about existing metadata.
-                    raise NotImplementedError(
-                        "_metadata file needed to `append` "
-                        "with `engine='pyarrow'` "
-                        "unless `ignore_divisions` is `True`"
-                    )
-                fmd = dataset.metadata
-            except (IOError, ValueError, IndexError):
-                # Original dataset does not exist - cannot append
-                append = False
-        if append:
-            arrow_schema = dataset.schema.to_arrow_schema()
+            arrow_schema = fmd.schema.to_arrow_schema()
             names = arrow_schema.names
             has_pandas_metadata = (
                 arrow_schema.metadata is not None and b"pandas" in arrow_schema.metadata
@@ -779,16 +796,13 @@ class ArrowDatasetEngine(Engine):
                         set(dtypes.items()) ^ set(df.dtypes.iteritems())
                     )
                 )
-            i_offset = len(dataset.pieces)
 
+            # Check divisions if necessary
             if division_info["name"] not in names:
                 ignore_divisions = True
             if not ignore_divisions:
                 old_end = None
-                row_groups = [
-                    dataset.metadata.row_group(i)
-                    for i in range(dataset.metadata.num_row_groups)
-                ]
+                row_groups = [fmd.row_group(i) for i in range(fmd.num_row_groups)]
                 for row_group in row_groups:
                     for i, name in enumerate(names):
                         if name != division_info["name"]:
@@ -1092,11 +1106,21 @@ class ArrowDatasetEngine(Engine):
         if index is None and index_names:
             index = index_names
 
-        if set(column_names).intersection(partitions):
-            raise ValueError(
-                "partition(s) should not exist in columns.\n"
-                "categories: {} | partitions: {}".format(column_names, partitions)
-            )
+        # Ensure that there is no overlap between partition columns
+        # and explicit column storage
+        if partitions:
+            _partitions = [p for p in partitions if p not in column_names]
+            if not _partitions:
+                partitions = []
+                partition_info["partitions"] = None
+                partition_info["partition_keys"] = {}
+                partition_info["partition_names"] = partitions
+            elif len(_partitions) != len(partitions):
+                raise ValueError(
+                    "No partition-columns should be written in the \n"
+                    "file unless they are ALL written in the file.\n"
+                    "columns: {} | partitions: {}".format(column_names, partitions)
+                )
 
         column_names, index_names = _normalize_index_columns(
             columns, column_names + partitions, index, index_names
@@ -1142,7 +1166,7 @@ class ArrowDatasetEngine(Engine):
                         index=meta.index,
                     )
 
-        return meta, index_cols, categories, index
+        return meta, index_cols, categories, index, partition_info
 
     @classmethod
     def _construct_parts(
@@ -1462,11 +1486,13 @@ class ArrowDatasetEngine(Engine):
             filters,
         )
 
-        # Check if we need to pass a fragment for each output partition
-        read_from_paths = read_from_paths or False
+        # Check if we need to pass a fragment for each output partition.
+        # By default, we will avoid passing fragments in the graph unless
+        # the user has specified `read_from_paths=False`
+        partitions = partition_info.get("partitions", None)
         pass_frags = (
             filters
-            and (not read_from_paths)
+            and (read_from_paths is False)
             and _need_fragments(filters, partition_info.get("partition_keys", None))
         )
 
@@ -1482,7 +1508,7 @@ class ArrowDatasetEngine(Engine):
             make_part_kwargs={
                 "fs": fs,
                 "partition_keys": partition_info.get("partition_keys", None),
-                "partition_obj": partition_info.get("partitions", None),
+                "partition_obj": partitions,
                 "data_path": data_path,
                 "frag_map": frag_map if pass_frags else None,
             },
@@ -1491,7 +1517,7 @@ class ArrowDatasetEngine(Engine):
         # Add common kwargs
         common_kwargs = {
             "partitioning": partition_info["partitioning"],
-            "partitions": partition_info["partitions"],
+            "partitions": partitions,
             "categories": categories,
             "filters": filters,
             "schema": schema,
@@ -2043,6 +2069,30 @@ class ArrowLegacyEngine(ArrowDatasetEngine):
         else:
             return meta
 
+    @classmethod
+    def _get_dataset_offset(cls, path, fs, append, ignore_divisions):
+        dataset = fmd = None
+        i_offset = 0
+        if append:
+            try:
+                # Allow append if the dataset exists.
+                # Also need dataset.metadata object if
+                # ignore_divisions is False (to check divisions)
+                dataset = pq.ParquetDataset(path, filesystem=fs)
+                if not dataset.metadata and not ignore_divisions:
+                    # TODO: Be more flexible about existing metadata.
+                    raise NotImplementedError(
+                        "_metadata file needed to `append` "
+                        "with `engine='pyarrow-legacy'` "
+                        "unless `ignore_divisions` is `True`"
+                    )
+                fmd = dataset.metadata
+                i_offset = len(dataset.pieces)
+            except (IOError, ValueError, IndexError):
+                # Original dataset does not exist - cannot append
+                append = False
+        return fmd, i_offset, append
+
 
 # Compatibility access to legacy ArrowEngine
 # (now called `ArrowLegacyEngine`)
