@@ -1,4 +1,5 @@
 import os
+import xml.etree.ElementTree
 from collections.abc import Set
 
 import pytest
@@ -48,6 +49,20 @@ def test_keys_values_items_to_dict_methods():
     assert hg.to_dict() == dict(hg)
 
 
+def test_keyset_deprecated():
+    a = {"x": 1, "y": (inc, "x")}
+    hg = HighLevelGraph({"a": a}, {"a": set()})
+    with pytest.warns(FutureWarning, match="HighLevelGraph.keys"):
+        assert hg.keyset() == hg.keys()
+
+
+def test_dicts_deprecated():
+    a = {"x": 1, "y": (inc, "x")}
+    hg = HighLevelGraph({"a": a}, {"a": set()})
+    with pytest.warns(FutureWarning, match="HighLevelGraph.layers"):
+        assert hg.dicts == hg.layers
+
+
 def test_getitem():
     hg = HighLevelGraph(
         {"a": {"a": 1, ("a", 0): 2, "b": 3}, "b": {"c": 4}}, {"a": set(), "b": set()}
@@ -127,6 +142,16 @@ def test_cull_layers():
         assert culled.dependencies[k] is hg.dependencies[k]
 
 
+def test_repr_html_hlg_layers():
+    hg = HighLevelGraph(
+        {"a": {"a": 1, ("a", 0): 2, "b": 3}, "b": {"c": 4}},
+        {"a": set(), "b": set()},
+    )
+    assert xml.etree.ElementTree.fromstring(hg._repr_html_()) is not None
+    for layer in hg.layers.values():
+        assert xml.etree.ElementTree.fromstring(layer._repr_html_()) is not None
+
+
 def annot_map_fn(key):
     return key[1:]
 
